:github_url: https://github.com/stephane-caron/qpsolvers/tree/master/doc/src/developer-notes.rst

***************
Developer notes
***************

Testing
=======

To run all CI checks locally, go to the repository folder and run

.. code:: bash

    tox -e py

This will run linters and unit tests.
